pub fn assert_partitions(
expected: &PartitionDef,
actual: &[PartitionInfo],
) -> Result<()>Expand description
Asserts the partitions are equal to the expected partitions.
pub fn assert_partitions(
expected: &PartitionDef,
actual: &[PartitionInfo],
) -> Result<()>Asserts the partitions are equal to the expected partitions.